SWDEV-341956 - update HIP Dtest with correct coordinates (#2755)

Change-Id: Iaccc4251a984e690d680ce884c6bfcc1093703af

[ROCm/hip commit: 2667f3e225]
This commit is contained in:
ROCm CI Service Account
2022-06-30 13:29:27 +05:30
committato da GitHub
parent 47a1198e18
commit da2888b9c4
11 ha cambiato i file con 24 aggiunte e 24 eliminazioni
@@ -34,7 +34,7 @@ DECLARE_DATA();
__global__ void print_things() {
DECLARE_DATA();
uint tid = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
uint tid = threadIdx.x + blockIdx.x * blockDim.x;
const char *msg[] = {msg_short, msg_long1, msg_long2};
printf("%s\n", msg[tid % 3]);